@@ -91,7 +91,7 @@ class DiscreteEnv(gym.Env):
     g = ((1/2)*(3-(2*(rho1)))*(self.state[1])+(1-(2*(rho1)))*((1+(self.state[1])**2)**0.5))
 
     #if action is 1 and rho (risk) high, intervene and discount Xa
-    if (action ==1):  & (rho2 >= 0.5)
+    if (action ==1) & (rho2 >= 0.5):
         new_Xa = g
     else:
         new_Xa = (self.state[1])  
